-- help.lua

local help_screen = {}

function help_screen.load(txt)
	ins = {  -- information regarding user inputs to control script
		fontsize	=  18,
		locX		=  15,		-- location of help window on screen
		locY		=   0,
		colortxt	= { 192, 192, 192, 255 },
		colorbg		= {  30,  30,  50, 210 },
		colorbrd	= { 255,   0,   0, 255 } -- border color
		}
		ins.height = #txt*ins.fontsize + ins.fontsize
		ins.canvasY= ins.height+2*ins.fontsize
		maxchr = 0
		for i = 1, #txt do if #txt[i]> maxchr then maxchr = #txt[i]+1 end end
		ins.width  = maxchr*ins.fontsize/2
		ins.canvasX = 2*ins.width+2*ins.fontsize
	gr.setFont( gr.newFont( ins.fontsize ) )
	cnv = gr.newCanvas( ins.canvasX, ins.canvasY )	-- create a canvas
	gr.setCanvas( cnv )								-- draw to canvas
		gr.setColor( unpack( ins.colorbg ) )		-- help background screen
		local mode	= 'fill'
		local x, y = ins.locX, ins.locY + ins.fontsize
		local width, height, cornerRadius = ins.width, ins.height, 10
		roundedRectangle( mode, x, y, width, height, cornerRadius )
		gr.setColor( unpack( ins.colorbrd ) )		-- add red border to window
		mode		= 'line'
		gr.setLineWidth( 2 )
		roundedRectangle( mode, x, y, width, height, cornerRadius )
		gr.setColor( unpack( ins.colortxt ) )	-- put text on screen
		for i = 1, #txt do
			gr.print( txt[i], ins.locX, ins.locY + ins.fontsize * i, 0, 1, 1 )
			end
		gr.setLineWidth( 1 )
		gr.setCanvas()					-- drawing to canvas complete
	end

function help_screen.draw()
	if help.show then
		gr.draw(cnv, 0, screenHeight-ins.canvasY, 0, 1, 1)
		end
	end

function help_screen.update() end
function help_screen.keyboard() end

function roundedRectangle(mode, x, y, width, height, cornerRadius) -- from Passion
    cornerRadius = cornerRadius or 0  -- if radius not specified, use rectangle
	if cornerRadius == 0 then
		gr.rectangle( mode, x, y, width, height )
		else
			local xround, yround = cornerRadius, cornerRadius
			local points = {}
			local precision = (xround + yround) * .3
			local tI, hP = table.insert, .5 * pi
			xround = xround > .5*width  and .5 * width  or xround
			yround = yround > .5*height and .5 * height or yround
			local X1, Y1, X2, Y2 = x + xround, y + yround, x + width - xround, y + height - yround
			for i = 0, precision do
				local a = (i / precision - 1) * hP
				tI(points, X2 + xround * cos(a))
				tI(points, Y1 + yround * sin(a))
				end
			for i = 0, precision do
				local a = (i / precision) * hP
				tI(points, X2 + xround * cos(a))
				tI(points, Y2 + yround * sin(a))
				end
			for i = 0, precision do
				local a = (i / precision + 1) * hP
				tI(points, X1 + xround * cos(a))
				tI(points, Y2 + yround * sin(a))
				end
			for i = 0, precision do
				local a = (i / precision + 2) * hP
				tI(points, X1 + xround * cos(a))
				tI(points, Y1 + yround * sin(a))
				end
			gr.polygon( mode, unpack(points) )  -- corners connected by default
		end
	end

return help_screen
