-- puddle.lua - a pixel effect

local puddle={}

function puddle.load()
	pud = love.graphics.newPixelEffect [[
		extern float x, y, rings, i, r, g, b;
		vec4 effect(vec4 global_color, Image texture, vec2 tc, vec2 pc )
		{vec4 pixel;
		//float root = sqrt(16*(x-tc.x)*(x-tc.x)/9+(y-tc.y)*(y-tc.y));
		float root = pow(1.0-(16*(x-tc.x)*(x-tc.x)/9+(y-tc.y)*(y-tc.y)),-3.0);
		float chg = root*sin(root*6.28*2.5*rings+3.14) / i;
		if (root <= 4.0 / rings)
			{
			pixel = Texel(texture, vec2( tc.x, tc.y ) );
			pixel.r = clamp( pixel.r + r * chg, 0, 1 );
			pixel.g = clamp( pixel.g + g * chg, 0, 1 );
			pixel.b = clamp( pixel.b + b * chg, 0, 1 );
			pixel.a = clamp( chg/root, 0.9, 1 );}
			else { pixel = Texel(texture, vec2( tc.x, tc.y ) );}
			return pixel;
			}
		]]
		pd = {
			x		= 0.5,
			y		= 0.5,
			rings	= 4,
			i		= 10,
			r		= 1,
			g		= 1,
			b		= 1
			}
	for i,j in pairs( pd ) do pud:send( i, j ) end
	txt = {
			"   Puddle Controls",
			" Intensity",
			"  <1><2>",
			" Color",
			"  <r>,<t>",
			"  <g><h>",
			"  <b><n>",
			" Help window:",
			"   <i> to close",
			" <esc> to exit script"
			}
			help.load(txt)
	help.show=true
	end

function puddle.draw()
	love.graphics.setPixelEffect( pud )
	gr.draw( image,0,0 )
	love.graphics.setPixelEffect()
	help.draw()
	end

function puddle.update( dt )
	pd.rings = pd.rings - dt/2
	if pd.rings < .4 then
		pd.rings = 4
		pd.x = math.random()
		pd.y = math.random()
		end
	pud:send( 'rings', pd.rings )
	pud:send( 'x', pd.x )
	pud:send( 'y', pd.y )
	end

function puddle.keypressed( key )
	if key == 'i'	then help.show	= not help.show end
	if key == '1'	then pd.i	= pd.i + 1						pud:send( 'i', pd.i ) end
	if key == '2'	then pd.i	= pd.i > 1 and pd.i -1 or 1		pud:send( 'i', pd.i ) end
	if key == 'r'	then pd.r 	= pd.r + .1						pud:send( 'r', pd.r ) end
	if key == 't'	then pd.r 	= pd.r > 0 and pd.r -0.1 or 0	pud:send( 'r', pd.r ) end
	if key == 'g'	then pd.g 	= pd.g + .1						pud:send( 'g', pd.g ) end
	if key == 'h'	then pd.g 	= pd.g > 0 and pd.g -0.1 or 0	pud:send( 'g', pd.g ) end
	if key == 'b'	then pd.b 	= pd.b + .1						pud:send( 'b', pd.b ) end
	if key == 'n'	then pd.b 	= pd.b > 0 and pd.b -0.1 or 0	pud:send( 'b', pd.b ) end
	end

return puddle
